Standard Matrices
==========================

.. contents::
    :depth: 2
    :local:

.. currentmodule:: cr.nimble

Random matrices
-------------------



.. autosummary::
    :toctree: _autosummary

    gaussian_mtx


Special matrices
----------------------------


.. autosummary::
    :toctree: _autosummary

    pascal
    pascal_jit
